<?php
/**

 * NOTICE OF LICENSE

 *

 * This file is licenced under the Software License Agreement.

 * With the purchase or the installation of the software in your application

 * you accept the licence agreement.

 *

 * You must not modify, adapt or create derivative works of this source code

 *

 *  @author    PopupMaker

 *  @copyright 2018 Sygnoos

 *  @license   LICENSE.txt

 */

class AdminPopupmakereditController extends ModuleAdminController
{
    public $existingUser = array();
    private $categories = array();
    private $products = array();
    private $frontCotrollers = array();
    private $currentId = null;

    public function __construct()
    {
        $this->display = 'view';
        $this->bootstrap = true;
        $this->existingUser = Tools::jsonDecode(Configuration::get('SGPM_POPUP_MAKER_API_OPTION'), true);
        if (!Tools::getIsset('index')) {
            $this->save();
        }
        $index = Tools::getValue('index');
        $popups = $this->existingUser['popups'];
        $ids = array_keys($popups);
        rsort($ids);
        $this->currentId = $ids[$index-1];
        $context = Context::getContext();
        $context->cookie->__set('popupId', $this->currentId);
        $this->setCategories(Category::getNestedCategories());
        $this->setFrontControllers();
        $this->setProducts();
        parent::__construct();
    }

    private function save()
    {
        $context = Context::getContext();
        $this->currentId = $context->cookie->popupId;
        $this->existingUser['popupsSettings'][$this->currentId]['categories'] = Tools::getValue('categories', array());
        $this->existingUser['popupsSettings'][$this->currentId]['frontControllers'] = Tools::getValue('frontControllers', array());
        $this->existingUser['popupsSettings'][$this->currentId]['products'] = Tools::getValue('products', array());
        Configuration::updateValue('SGPM_POPUP_MAKER_API_OPTION', Tools::jsonEncode($this->existingUser));
        $context->cookie->__set('popupId', null);
        Tools::redirectAdmin($context->link->getAdminLink('AdminPopupmakerpopups'));
    }

    public function initToolBarTitle()
    {
        $this->toolbar_title = $this->l('Edit Popup');
    }

    public function setMedia($isNewTheme = false)
    {
        parent::setMedia();

        $module_path = $this->module->getPathUri();

        $this->addJS(array(
            $module_path.'views/js/main.js'

        ));

        return true;
    }

    public function initContent()
    {
        parent::initContent();

        $this->content .= $this->renderForm();
        $this->context->smarty->assign(array('content' => $this->content));
    }

    private function setCategories($categoriesArray)
    {
        foreach ($categoriesArray as $category) {
            $this->categories[] = array('category_id' => $category['id_category'], 'name' => $category['name']);
            if (!empty($category['children'])) {
                $this->setCategories($category['children']);
            }
        }
    }

    private function setFrontControllers()
    {
        $controllers = Dispatcher::getControllers(_PS_FRONT_CONTROLLER_DIR_);
        foreach ($controllers as $key => $value) {
            $this->frontCotrollers[] = array('controller_id' => $value, 'controller' => $key);
        }
    }

    private function setProducts()
    {
        $products = Product::getProducts(1, 0, 0, 'id_product', 'DESC');
        foreach ($products as $product) {
            $this->products[] = array('product_id' => $product['id_product'], 'name' => $product['name']);
        }
    }

    public function renderForm()
    {
        if (empty($this->existingUser['popupsSettings'][$this->currentId])) {
            $this->existingUser['popupsSettings'][$this->currentId] = array('status' => SGPM_POPUP_STATUS_DISABLED);
        }

        $popupOptions = $this->existingUser['popupsSettings'][$this->currentId];
        $this->fields_value = array(
            'description' => 'Please choose pages on which popup will be shown',
            'categories[]' => empty($popupOptions['categories']) ? '' : $popupOptions['categories'],
            'frontControllers[]' => empty($popupOptions['frontControllers']) ? '' : $popupOptions['frontControllers'],
            'products[]' => empty($popupOptions['products']) ? '' : $popupOptions['products']
        );
        $this->fields_form = array(
            'legend' => array(
                'title' => 'Please choose pages on which popup will be shown'
            ),
            'input' => array(

                array(
                    'type' => 'select',
                    'label' => 'Categories',
                    'name' => 'categories[]',
                    'class' => 'chosen',
                    'multiple' => true,
                    'options' => array(
                        'query' => $this->categories,
                        'id' => 'category_id',
                        'name' => 'name'
                    )
                ),
                array(
                    'type' => 'select',
                    'label' => 'Front Controllers',
                    'name' => 'frontControllers[]',
                    'class' => 'chosen',
                    'multiple' => true,
                    'options' => array(
                        'query' => $this->frontCotrollers,
                        'id' => 'controller_id',
                        'name' => 'controller'
                    )
                ),
                array(
                    'type' => 'select',
                    'label' => 'Products',
                    'name' => 'products[]',
                    'class' => 'chosen',
                    'multiple' => true,
                    'options' => array(
                        'query' => $this->products,
                        'id' => 'product_id',
                        'name' => 'name'
                    )
                )
            ),
            'submit' => array(
                'title' => 'Save',
            )
        );
        return parent::renderForm();
    }

    public function renderView()
    {
        return parent::renderView();
    }
}
