<?php
/**

 * NOTICE OF LICENSE

 *

 * This file is licenced under the Software License Agreement.

 * With the purchase or the installation of the software in your application

 * you accept the licence agreement.

 *

 * You must not modify, adapt or create derivative works of this source code

 *

 *  @author    PopupMaker

 *  @copyright 2018 Sygnoos

 *  @license   LICENSE.txt

 */

require_once(dirname(__FILE__).'/../../config/config.php');

class AdminPopupmakerpopupsController extends ModuleAdminController
{
    public $name = 'popups';
    public $existingUser = array();

    public function __construct()
    {
        $this->display = 'view';
        $this->bootstrap = true;
        refreshUser();
        $this->existingUser = Tools::jsonDecode(Configuration::get('SGPM_POPUP_MAKER_API_OPTION'), true);
        parent::__construct();

        if (Tools::getIsset('status'.$this->name)) {
            $this->changeStatus(Tools::getValue('id'));
        } else if (Tools::getIsset('update'.$this->name)) {
            Tools::redirectAdmin($this->context->link->getAdminLink('AdminPopupmakeredit').'&index='.Tools::getValue('id'));
        }
    }

    private function changeStatus($index)
    {
        if (empty($this->existingUser)) {
            return;
        }
        $index = (int)$index;
        $index--;
        $popups = $this->existingUser['popups'];
        $ids = array_keys($popups);
        rsort($ids);
        $id = $ids[$index];
        $popupsSettings = !empty($this->existingUser['popupsSettings']) ? $this->existingUser['popupsSettings'] : array();
        if (!empty($popupsSettings[$id]) && $popupsSettings[$id]['status'] == SGPM_POPUP_STATUS_ENABLED) {
            $popupsSettings[$id]['status'] = SGPM_POPUP_STATUS_DISABLED;
        } else {
            $popupsSettings[$id]['status'] = SGPM_POPUP_STATUS_ENABLED;
        }
        $this->existingUser['popupsSettings'] = $popupsSettings;
        Configuration::updateValue('SGPM_POPUP_MAKER_API_OPTION', Tools::jsonEncode($this->existingUser));
        Tools::redirectAdmin($this->context->link->getAdminLink('AdminPopupmakerpopups'));
    }

    public function initToolBarTitle()
    {
        if (!empty($this->existingUser)) {
            $this->toolbar_title = $this->l('Popups');
        } else {
            $this->toolbar_title = $this->l('API Credentials');
        }
    }


    public function setMedia($isNewTheme = false)
    {
        parent::setMedia();

        $module_path = $this->module->getPathUri();

        $this->addCss(array(
            $module_path.'views/css/main.css'
        ));

        $this->addJS(array(
            $module_path.'views/js/main.js'

        ));

        return true;
    }

    public function initContent()
    {

        parent::initContent();

        if (empty($this->existingUser)) {
            $this->content .= $this->renderForm();
        } else {
            $this->content .= $this->renderList($this->existingUser);
        }

        $this->context->smarty->assign(array('content' => $this->content));
    }

    public function renderForm()
    {
        $this->fields_value = array(
            'description' => 'Please, connect to your Popup Maker account via API key to start using the plugin.<br/>Don’t have an account? <a target="_blank" href="https://popupmaker.com/signup?utm_source=prestashop&utm_medium=website">Click here to create a Popup Maker account.</a> This will take only 30 seconds!'
        );

        $this->fields_form = array(
            'input' => array(
                array(
                'type' => 'free',
                'label' => '',
                'name' => 'description'
                ),
                array(
                    'type' => 'textbutton',
                    'label' => 'API Key',
                    'name' => 'sgpm-field-key',
                    'desc' => 'You can find your API key in the <a target="_blank" href="https://popupmaker.com/settings/index?utm_source=prestashop&utm_medium=website">Settings section</a> of your Popup Maker account.',
                    'button' => array(
                        'label' => 'Connect',
                        'attributes' => array(
                            'onclick' => 'connect()'
                        )
                    )
                )
            )
        );

        return parent::renderForm();
    }

    public function renderList($existingUser = array())
    {

        $popups = !empty($existingUser['popups']) ? $existingUser['popups'] : array();
        krsort($popups);
        $popupsSettings = !empty($existingUser['popupsSettings']) ? $existingUser['popupsSettings'] : array();

        $i = 1;
        $content = array();
        foreach ($popups as $popupId => $popup) {
            array_push($content, array(
                'id' => $i++,
                'title' => $popup['title'],
                'status' => (!empty($popupsSettings[$popupId]) && $popupsSettings[$popupId]['status'] == 'enabled') ? 1 : 0
            ));
        }

        $fields_list = array(
            'id' => array(
                'title' => 'Id'
            ),
            'title' => array(
                'title' => 'Popup name',
                'align' => 'center'
            ),

            'status' => array(
                'title' => 'Is enabled',
                'type' => 'bool',
                'active' => 'status'
            )
        );

        $helper = new HelperList();
        $helper->shopLinkType = '';
        $helper->simple_header = true;
        $helper->actions = array("edit");
        $helper->show_toolbar = false;
        $helper->module = $this;
        $helper->listTotal = count($content);
        $helper->identifier = 'id';
        $helper->table = $this->name;
        $helper->title = 'Popups ('.count($popups).')';
        $helper->token = Tools::getAdminTokenLite('AdminPopupmakerpopups');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;

        return $helper->generateList($content, $fields_list);
    }

    public function renderView()
    {

        $this->tpl_view_vars = array(
            'isConnected' => !empty($this->existingUser)
        );

        return parent::renderView();
    }
}
