<?php
/**

 * NOTICE OF LICENSE

 *

 * This file is licenced under the Software License Agreement.

 * With the purchase or the installation of the software in your application

 * you accept the licence agreement.

 *

 * You must not modify, adapt or create derivative works of this source code

 *

 *  @author    PopupMaker

 *  @copyright 2018 Sygnoos

 *  @license   LICENSE.txt

 */

function connect($apiKey)
{
    $user = getUserByApiKey($apiKey);
    return !empty($user) && $user['isAuthenticate'];
}

function disconnect()
{
    Configuration::updateValue('SGPM_POPUP_MAKER_API_OPTION', Tools::jsonEncode(array()));
    return true;
}

function getUserByApiKey($apiKey)
{
    $existingUser = Tools::jsonDecode(Configuration::get('SGPM_POPUP_MAKER_API_OPTION'), true);

    if (!$apiKey && $existingUser['oldUser'] && $existingUser['isAuthenticate'] && $existingUser['apiKey']) {
        $apiKey = $existingUser['apiKey'];
    }

    $data = getData($apiKey);

    if (empty($data)) {
        Configuration::updateValue('SGPM_POPUP_MAKER_API_OPTION', Tools::jsonEncode($data));
        return $data;
    }
    if (empty($existingUser) || !$existingUser) {
        $existingUser = array();
    }
    $existingUser['apiKey'] = '';
    $existingUser['isAuthenticate'] = false;

    if (isset($data['isAuthenticate']) && $data['isAuthenticate']) {
        $existingUser['oldUser'] = true;
        $existingUser['isAuthenticate'] = true;
        $existingUser['apiKey'] = $data['apiKey'];
        $existingUser['popups'] = array_reverse($data['popups'], true);
        $existingUser['user'] = $data['user'];
    }

    // enable last created popup
    if (empty($existingUser['popupsSettings'])) {
        $isEnabled = false;
        foreach ($existingUser['popups'] as $popupId => $popup) {
            if (!$isEnabled) {
                $existingUser['popupsSettings'][$popupId]['status'] = SGPM_POPUP_STATUS_ENABLED;
                $isEnabled = true;
            } else {
                $existingUser['popupsSettings'][$popupId]['status'] = SGPM_POPUP_STATUS_DISABLED;
            }
        }
    }

    Configuration::updateValue('SGPM_POPUP_MAKER_API_OPTION', Tools::jsonEncode($existingUser));

    return $existingUser;
}

function refreshUser()
{
    $existingUser = Tools::jsonDecode(Configuration::get('SGPM_POPUP_MAKER_API_OPTION'), true);

    if (!empty($existingUser) && $existingUser['apiKey']) {
        $apiKey = $existingUser['apiKey'];
        $user = getUserByApiKey($apiKey);
        return !empty($user) && $user['isAuthenticate'];
    }

    return false;
}

function getData($apiKey)
{
    $connectUrl = SGPM_SERVICE_URL.'app/connect';
    $hostname = parse_url($connectUrl, PHP_URL_HOST);

    if ($hostname == false) {
        return false;
    }

    $dns_records = dns_get_record($hostname, DNS_AAAA + DNS_A);
    $host_has_ipv6 = false;
    $host_has_ipv4 = false;
    $result = false;
    foreach ($dns_records as $dns_record) {
        if (isset($dns_record['type'])) {
            switch ($dns_record['type']) {
                case 'AAAA':
                    $host_has_ipv6 = true;
                    break;
                case 'A':
                    $host_has_ipv4 = true;
                    break;
            }
        }
    }

    $data = array(
        'apiKey' => $apiKey,
        'appname' => 'Prestashop'
    );

    $options = array(
        'http' => array(
            'header'  => "Content-type: application/x-www-form-urlencoded\r\n",
            'method'  => 'POST',
            'content' => http_build_query($data)
        )
    );

    if ($host_has_ipv6 === true) {
        $options['socket'] = array('bindto' => '[0]:0');
        $context  = stream_context_create($options);
        $result = Tools::file_get_contents($connectUrl, false, $context);
    }

    if ($host_has_ipv4 === true && $result == false) {
        $options['socket'] = array('bindto' => '0:0');
        $context  = stream_context_create($options);
        $result = Tools::file_get_contents($connectUrl, false, $context);
    }

    $data = json_decode($result, true);
    return $data;
}
