<?php
/**

 * NOTICE OF LICENSE

 *

 * This file is licenced under the Software License Agreement.

 * With the purchase or the installation of the software in your application

 * you accept the licence agreement.

 *

 * You must not modify, adapt or create derivative works of this source code

 *

 *  @author    PopupMaker

 *  @copyright 2018 Sygnoos

 *  @license   LICENSE.txt

 */

if (!defined('_PS_VERSION_')) {
    exit;
}

require_once(dirname(__FILE__).'/config/config.php');

class PopupMaker extends Module
{
    public function __construct()
    {
        $this->name = 'popupmaker';
        $this->tab = 'dashboard';
        $this->version = '1.0.0';
        $this->author = 'Sygnoos';
        $this->module_key = 'cf845404d4c47f576959d85487b66ccd';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('PopupMaker');
        $this->description = $this->l('Manage your popups');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
    }

    public function install()
    {
        if (Shop::isFeatureActive()) {
            Shop::setContext(Shop::CONTEXT_ALL);
        }
        $this->installTabItems();
        Configuration::updateValue('SGPM_POPUP_MAKER_API_OPTION', Tools::jsonEncode(array()));
        return parent::install() &&
            $this->registerHook('displayBackOfficeHeader')
            && $this->registerHook('displayAfterBodyOpeningTag');
    }

    public function hookDisplayBackOfficeHeader()
    {
        //add tab icon (only for 1.7+ versions)
        if (version_compare(_PS_VERSION_, '1.7.0.0') >= 0) {
            $bgId = (int)Tab::getIdFromClassName('AdminPopupmaker');
            $css = '<style>.page-sidebar-closed li[data-submenu="'.$bgId.'"] i.material-icons:before';
            $css .= '{content: "filter";}</style>';
        }

        //add tab icons for all other cases
        $this->context->controller->addCss($this->_path.'views/css/tab.css');

        return $css;
    }

    public function hookDisplayAfterBodyOpeningTag($params)
    {
        $currentController = $this->context->controller;
        $popupHashes = array();
        $existingUser = Tools::jsonDecode(Configuration::get('SGPM_POPUP_MAKER_API_OPTION'), true);
        if (!empty($existingUser) && !empty($existingUser['popupsSettings'])) {
            $popups = $existingUser['popups'];
            foreach ($existingUser['popupsSettings'] as $popupId => $settings) {
                if ($settings['status'] == SGPM_POPUP_STATUS_DISABLED) {
                    continue;
                }
                //check controllers
                $controllers = empty($settings['frontControllers']) ? array() : $settings['frontControllers'];
                foreach ($controllers as $controller) {
                    if ($currentController instanceof $controller) {
                        $popupHashes[] = $popups[$popupId]['hashId'];
                    }
                }

                //check products
                if ($currentController instanceof ProductController) {
                    $products = empty($settings['products']) ? array() : $settings['products'];
                    $currentProductId = $currentController->getProduct()->id;
                    foreach ($products as $product) {
                        $productId = (int)$product;
                        if ($productId == $currentProductId) {
                            $popupHashes[] = $popups[$popupId]['hashId'];
                        }
                    }
                }

                //check category
                if ($currentController instanceof CategoryController) {
                    $categories = empty($settings['categories']) ? array() : $settings['categories'];
                    $currentCategory = $currentController->getCategory()->id;
                    foreach ($categories as $category) {
                        $categoryId = (int) $category;
                        if ($categoryId == $currentCategory) {
                            $popupHashes[] = $popups[$popupId]['hashId'];
                        }
                    }
                }
            }
        }

        $smarty = $this->context->smarty;
        $smarty->clearCompiledTemplate(_PS_MODULE_DIR_.'popupmaker/views/templates/hook/embed_script.tpl');
        $smarty->assign(array('popupHashes' => $popupHashes));
        return $smarty->fetch(_PS_MODULE_DIR_.'popupmaker/views/templates/hook/embed_script.tpl');
    }

    public function uninstall()
    {
        $this->uninstallTabItem('AdminPopupmakerpopups');
        $this->uninstallTabItem('AdminPopupmakersupport');
        $this->uninstallTabItem('AdminPopupmakeredit');
        $this->uninstallTabItem('AdminPopupmaker');
        return parent::uninstall();
    }

    private function installTabItems()
    {
        $parentTab = 'AdminTools';
        //we are running prestashop 1.6
        if (version_compare(_PS_VERSION_, '1.7.0.0')<0) {
            $parentTab = null;
        }

        $this->installOnTab('popupmaker', $parentTab, 'AdminPopupmaker', 'Popup Maker');
        $this->installOnTab('popupmaker', 'AdminPopupmaker', 'AdminPopupmakerpopups', 'Popups');
        $this->installOnTab('popupmaker', 'AdminPopupmaker', 'AdminPopupmakersupport', 'Support');
        $this->installOnTab('popupmaker', -1, 'AdminPopupmakeredit', 'Edit');
    }

    private function uninstallTabItem($tabClass)
    {
        $tabId = Tab::getIdFromClassName($tabClass);
        if ($tabId) {
            $tab = new Tab((int)$tabId);
            $tab->delete();
        }
    }

    private function installOnTab($moduleName, $tabParentClass, $tabClass, $tabName)
    {
        if (!$tabId = Tab::getIdFromClassName($tabClass)) {
            $tab = new Tab();
            $tab->class_name = $tabClass;
            $tab->module = $moduleName;
            $tab->id_parent = 0;
            if ($tabParentClass) {
                if ($tabParentClass == -1) {
                    $tab->id_parent = -1;
                } else {
                    $tab->id_parent = (int)Tab::getIdFromClassName($tabParentClass);
                }
            }

            foreach (Language::getLanguages(false) as $lang) {
                $tab->name[(int)$lang['id_lang']] = $tabName;
            }

            $tab->save();
        } else {
            $tab = new Tab((int)$tabId);
        }
    }

    public function getContent()
    {
        Tools::redirectAdmin($this->context->link->getAdminLink('AdminPopupmakerpopups'));
    }
}
